Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(805)

Unified Diff: components/user_prefs/tracked/pref_hash_filter.cc

Issue 1549993003: Switch to standard integer types in components/, part 4 of 4. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/user_prefs/tracked/pref_hash_filter.cc
diff --git a/components/user_prefs/tracked/pref_hash_filter.cc b/components/user_prefs/tracked/pref_hash_filter.cc
index d3cd61d714bb3694ba4cf3eb96e8527ab169fdee..ac27892ec4a39af7b106b3603e9b7c853dc2a0f7 100644
--- a/components/user_prefs/tracked/pref_hash_filter.cc
+++ b/components/user_prefs/tracked/pref_hash_filter.cc
@@ -4,9 +4,12 @@
#include "components/user_prefs/tracked/pref_hash_filter.h"
+#include <stdint.h>
+
#include <algorithm>
#include "base/logging.h"
+#include "base/macros.h"
#include "base/metrics/histogram.h"
#include "base/prefs/pref_service.h"
#include "base/prefs/pref_store.h"
@@ -110,11 +113,11 @@ base::Time PrefHashFilter::GetResetTime(PrefService* user_prefs) {
// order to ensure it remains consistent with the way we store this value
// (which we do via a PrefStore, preventing us from reusing
// PrefService::SetInt64).
- int64 internal_value = base::Time().ToInternalValue();
+ int64_t internal_value = base::Time().ToInternalValue();
if (!base::StringToInt64(
user_prefs->GetString(user_prefs::kPreferenceResetTime),
&internal_value)) {
// Somehow the value stored on disk is not a valid int64.
NOTREACHED();
return base::Time();
}
@@ -110,11 +113,11 @@ base::Time PrefHashFilter::GetResetTime(PrefService* user_prefs) {
user_prefs->GetString(user_prefs::kPreferenceResetTime),
&internal_value)) {
- // Somehow the value stored on disk is not a valid int64.
+ // Somehow the value stored on disk is not a valid int64_t.
NOTREACHED();
return base::Time();
« no previous file with comments | « components/user_prefs/tracked/pref_hash_filter.h ('k') | components/user_prefs/tracked/pref_hash_filter_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698